/* Runs in a separate process and communicates using process.on('message', ...) */
/* This is because tslint is implemented synchronously */
"use strict";
var Linter = require('tslint');
var fs_1 = require('fs');
var options = {
    configuration: undefined,
    formatter: 'prose',
    formattersDirectory: undefined,
    rulesDirectory: undefined
};
process.on('message', function (msg) {
    var success = true;
    msg.filesToLint.forEach(function (fileName) {
        var contents = fs_1.readFileSync(fileName, 'utf8');
        var linter = new Linter(fileName, contents, options);
        var results = linter.lint();
        results.failures.forEach(function (failure) {
            success = false;
            var response = {
                violation: {
                    fileName: fileName,
                    line: failure.getStartPosition().getLineAndCharacter().line + 1,
                    column: failure.getStartPosition().getLineAndCharacter().character,
                    message: failure.getFailure()
                }
            };
            process.send(response);
        });
    });
    process.send({ finished: { success: success } });
});
var configurationFile = Linter.loadConfigurationFromPath(process.cwd() + '/tslint.json');
options.configuration = { rules: configurationFile.rules };
options.rulesDirectory = configurationFile.rulesDirectory;
//# sourceMappingURL=linter-process.js.map