"use strict";
var inquirer_1 = require('inquirer');
var path_1 = require('path');
exports.release = function (toolbox) {
    var git = toolbox.git, taskRunner = toolbox.taskRunner, logger = toolbox.logger;
    return git.execute(['status', '--porcelain']).then(function (modifiedFiles) {
        if (modifiedFiles.length > 0) {
            throw new Error('There are uncommitted changes in the working tree');
        }
        var npm = path_1.sep === '\\' ? 'npm.cmd' : 'npm';
        return inquirer_1.prompt({
            type: 'list',
            name: 'bump',
            message: 'What type of bump would you like to do?',
            choices: ['patch', 'minor', 'major']
        }).then(function (answers) {
            var importance = answers['bump'];
            return taskRunner.runTask(npm, ['version', importance], { name: 'npm', logger: logger }).result.then(function () {
                // 'npm version' also does a 'git commit' and 'git tag'
                return git.execute(['push']).then(function () {
                    return git.execute(['push', '--tags']).then(function () {
                        return taskRunner.runTask(npm, ['publish'], { name: 'npm', logger: logger }).result;
                    });
                });
            });
        });
    });
};
//# sourceMappingURL=release.js.map